package com.persagy.transfer.pojo.dto;

import com.baomidou.mybatisplus.annotation.FieldStrategy;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.baomidou.mybatisplus.extension.handlers.FastjsonTypeHandler;
import com.persagy.common.model.BaseEntity;
import com.persagy.common.utils.StringUtil;

import lombok.EqualsAndHashCode;
import lombok.Getter;
import lombok.Setter;
import lombok.ToString;

/**
 * 信息点定义表
 * 
 * @version 1.0.0
 * @company persagy
 * @author zhangqiankun
 * @date 2021-09-16 13:16:57
 */
@Getter
@Setter
@ToString
@EqualsAndHashCode(callSuper = false)
@TableName("rwd_def_funcid_wd")
public class RwdDefFuncidWd extends BaseEntity<RwdDefFuncidWd> {
	private static final long serialVersionUID = -8446926744906458866L;

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String code; // 信息点编码,同类型下唯一,标准驼峰格式

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String origCode; // 信息点编码,同类型下唯一,旧版版格式,非驼峰,已弃用

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String name; // 信息点名称

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String aliasCode; // 编码别名

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String aliasName; // 别名

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String classCode; // 类型编码

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String type; // 平台级common,集团级group,项目级project

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String groupCode; // 集团编码

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String projectId; // 项目id

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String category; // 信息点分类:静态,脉冲,阶段,时序

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String firstTag; // 一级标签

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String aliasFirstTag; // 一级标签别名

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String secondTag; // 二级标签

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String aliasSecondTag; // 二级标签别名

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String priority; // 优先级

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String inputMode; // 输入方式

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String unit; // 单位

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String dataType; // 数据类型

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String origDataType; // 原数据类型,已弃用

	@TableField(updateStrategy = FieldStrategy.NOT_NULL)
	private Integer isMultiple; // 是否复数

	@TableField(updateStrategy = FieldStrategy.NOT_NULL)
	private Integer isRegion; // 是否区间

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String formater; // 数据格式

	@TableField(typeHandler = FastjsonTypeHandler.class)
	private Object dataSource; // 数据源取值范围/枚举值清单等,根据dataType有不同的内容

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String origDataSource; // 数据源取值范围/枚举值清单等,根据dataType有不同的内容,原始定义

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String note; // 备注

	@TableField(updateStrategy = FieldStrategy.NOT_NULL)
	private Integer subFlag; // 子分类标记:是否可以按此信息点进行子分类替换,同一类型下目前只支持一个子分类信息点

	@TableField(updateStrategy = FieldStrategy.NOT_NULL)
	private Integer weakPoint; // 虚点

	public static Builder builder() {
		return new Builder();
	}

	public static class BuilderQueryWrapper {

		private LambdaQueryWrapper<RwdDefFuncidWd> queryWrapper = new LambdaQueryWrapper<RwdDefFuncidWd>();

		public BuilderQueryWrapper idEq(String id) {
			if (StringUtil.isNotBlank(id)) {
				queryWrapper.eq(RwdDefFuncidWd::getId, id);
			}
			return this;
		}

		public BuilderQueryWrapper codeEq(String code) {
			if (StringUtil.isNotBlank(code)) {
				queryWrapper.eq(RwdDefFuncidWd::getCode, code);
			}
			return this;
		}

		public BuilderQueryWrapper origCodeEq(String origCode) {
			if (StringUtil.isNotBlank(origCode)) {
				queryWrapper.eq(RwdDefFuncidWd::getOrigCode, origCode);
			}
			return this;
		}

		public BuilderQueryWrapper nameEq(String name) {
			if (StringUtil.isNotBlank(name)) {
				queryWrapper.eq(RwdDefFuncidWd::getName, name);
			}
			return this;
		}

		public BuilderQueryWrapper aliasCodeEq(String aliasCode) {
			if (StringUtil.isNotBlank(aliasCode)) {
				queryWrapper.eq(RwdDefFuncidWd::getAliasCode, aliasCode);
			}
			return this;
		}

		public BuilderQueryWrapper aliasNameEq(String aliasName) {
			if (StringUtil.isNotBlank(aliasName)) {
				queryWrapper.eq(RwdDefFuncidWd::getAliasName, aliasName);
			}
			return this;
		}

		public BuilderQueryWrapper classCodeEq(String classCode) {
			if (StringUtil.isNotBlank(classCode)) {
				queryWrapper.eq(RwdDefFuncidWd::getClassCode, classCode);
			}
			return this;
		}

		public BuilderQueryWrapper typeEq(String type) {
			if (StringUtil.isNotBlank(type)) {
				queryWrapper.eq(RwdDefFuncidWd::getType, type);
			}
			return this;
		}

		public BuilderQueryWrapper groupCodeEq(String groupCode) {
			if (StringUtil.isNotBlank(groupCode)) {
				queryWrapper.eq(RwdDefFuncidWd::getGroupCode, groupCode);
			}
			return this;
		}

		public BuilderQueryWrapper projectIdEq(String projectId) {
			if (StringUtil.isNotBlank(projectId)) {
				queryWrapper.eq(RwdDefFuncidWd::getProjectId, projectId);
			}
			return this;
		}

		public BuilderQueryWrapper categoryEq(String category) {
			if (StringUtil.isNotBlank(category)) {
				queryWrapper.eq(RwdDefFuncidWd::getCategory, category);
			}
			return this;
		}

		public BuilderQueryWrapper firstTagEq(String firstTag) {
			if (StringUtil.isNotBlank(firstTag)) {
				queryWrapper.eq(RwdDefFuncidWd::getFirstTag, firstTag);
			}
			return this;
		}

		public BuilderQueryWrapper aliasFirstTagEq(String aliasFirstTag) {
			if (StringUtil.isNotBlank(aliasFirstTag)) {
				queryWrapper.eq(RwdDefFuncidWd::getAliasFirstTag, aliasFirstTag);
			}
			return this;
		}

		public BuilderQueryWrapper secondTagEq(String secondTag) {
			if (StringUtil.isNotBlank(secondTag)) {
				queryWrapper.eq(RwdDefFuncidWd::getSecondTag, secondTag);
			}
			return this;
		}

		public BuilderQueryWrapper aliasSecondTagEq(String aliasSecondTag) {
			if (StringUtil.isNotBlank(aliasSecondTag)) {
				queryWrapper.eq(RwdDefFuncidWd::getAliasSecondTag, aliasSecondTag);
			}
			return this;
		}

		public BuilderQueryWrapper priorityEq(String priority) {
			if (StringUtil.isNotBlank(priority)) {
				queryWrapper.eq(RwdDefFuncidWd::getPriority, priority);
			}
			return this;
		}

		public BuilderQueryWrapper inputModeEq(String inputMode) {
			if (StringUtil.isNotBlank(inputMode)) {
				queryWrapper.eq(RwdDefFuncidWd::getInputMode, inputMode);
			}
			return this;
		}

		public BuilderQueryWrapper unitEq(String unit) {
			if (StringUtil.isNotBlank(unit)) {
				queryWrapper.eq(RwdDefFuncidWd::getUnit, unit);
			}
			return this;
		}

		public BuilderQueryWrapper dataTypeEq(String dataType) {
			if (StringUtil.isNotBlank(dataType)) {
				queryWrapper.eq(RwdDefFuncidWd::getDataType, dataType);
			}
			return this;
		}

		public BuilderQueryWrapper origDataTypeEq(String origDataType) {
			if (StringUtil.isNotBlank(origDataType)) {
				queryWrapper.eq(RwdDefFuncidWd::getOrigDataType, origDataType);
			}
			return this;
		}

		public BuilderQueryWrapper isMultipleEq(Integer isMultiple) {
			if (null != isMultiple) {
				queryWrapper.eq(RwdDefFuncidWd::getIsMultiple, isMultiple);
			}
			return this;
		}

		public BuilderQueryWrapper isRegionEq(Integer isRegion) {
			if (null != isRegion) {
				queryWrapper.eq(RwdDefFuncidWd::getIsRegion, isRegion);
			}
			return this;
		}

		public BuilderQueryWrapper formaterEq(String formater) {
			if (StringUtil.isNotBlank(formater)) {
				queryWrapper.eq(RwdDefFuncidWd::getFormater, formater);
			}
			return this;
		}

		public BuilderQueryWrapper dataSourceEq(Object dataSource) {
			if (null != dataSource) {
				queryWrapper.eq(RwdDefFuncidWd::getDataSource, dataSource);
			}
			return this;
		}

		public BuilderQueryWrapper origDataSourceEq(String origDataSource) {
			if (StringUtil.isNotBlank(origDataSource)) {
				queryWrapper.eq(RwdDefFuncidWd::getOrigDataSource, origDataSource);
			}
			return this;
		}

		public BuilderQueryWrapper noteEq(String note) {
			if (StringUtil.isNotBlank(note)) {
				queryWrapper.eq(RwdDefFuncidWd::getNote, note);
			}
			return this;
		}

		public BuilderQueryWrapper subFlagEq(Integer subFlag) {
			if (null != subFlag) {
				queryWrapper.eq(RwdDefFuncidWd::getSubFlag, subFlag);
			}
			return this;
		}

		public BuilderQueryWrapper weakPointEq(Integer weakPoint) {
			if (null != weakPoint) {
				queryWrapper.eq(RwdDefFuncidWd::getWeakPoint, weakPoint);
			}
			return this;
		}

		public LambdaQueryWrapper<RwdDefFuncidWd> builder() {
			return queryWrapper;
		}

	}

	public static class BuilderUpdateWrapper {

		private LambdaUpdateWrapper<RwdDefFuncidWd> updateWrapper = new LambdaUpdateWrapper<RwdDefFuncidWd>();

		public BuilderUpdateWrapper idEq(String id) {
			if (StringUtil.isNotBlank(id)) {
				updateWrapper.eq(RwdDefFuncidWd::getId, id);
			}
			return this;
		}

		public BuilderUpdateWrapper codeEq(String code) {
			if (StringUtil.isNotBlank(code)) {
				updateWrapper.eq(RwdDefFuncidWd::getCode, code);
			}
			return this;
		}

		public BuilderUpdateWrapper origCodeEq(String origCode) {
			if (StringUtil.isNotBlank(origCode)) {
				updateWrapper.eq(RwdDefFuncidWd::getOrigCode, origCode);
			}
			return this;
		}

		public BuilderUpdateWrapper nameEq(String name) {
			if (StringUtil.isNotBlank(name)) {
				updateWrapper.eq(RwdDefFuncidWd::getName, name);
			}
			return this;
		}

		public BuilderUpdateWrapper aliasCodeEq(String aliasCode) {
			if (StringUtil.isNotBlank(aliasCode)) {
				updateWrapper.eq(RwdDefFuncidWd::getAliasCode, aliasCode);
			}
			return this;
		}

		public BuilderUpdateWrapper aliasNameEq(String aliasName) {
			if (StringUtil.isNotBlank(aliasName)) {
				updateWrapper.eq(RwdDefFuncidWd::getAliasName, aliasName);
			}
			return this;
		}

		public BuilderUpdateWrapper classCodeEq(String classCode) {
			if (StringUtil.isNotBlank(classCode)) {
				updateWrapper.eq(RwdDefFuncidWd::getClassCode, classCode);
			}
			return this;
		}

		public BuilderUpdateWrapper typeEq(String type) {
			if (StringUtil.isNotBlank(type)) {
				updateWrapper.eq(RwdDefFuncidWd::getType, type);
			}
			return this;
		}

		public BuilderUpdateWrapper groupCodeEq(String groupCode) {
			if (StringUtil.isNotBlank(groupCode)) {
				updateWrapper.eq(RwdDefFuncidWd::getGroupCode, groupCode);
			}
			return this;
		}

		public BuilderUpdateWrapper projectIdEq(String projectId) {
			if (StringUtil.isNotBlank(projectId)) {
				updateWrapper.eq(RwdDefFuncidWd::getProjectId, projectId);
			}
			return this;
		}

		public BuilderUpdateWrapper categoryEq(String category) {
			if (StringUtil.isNotBlank(category)) {
				updateWrapper.eq(RwdDefFuncidWd::getCategory, category);
			}
			return this;
		}

		public BuilderUpdateWrapper firstTagEq(String firstTag) {
			if (StringUtil.isNotBlank(firstTag)) {
				updateWrapper.eq(RwdDefFuncidWd::getFirstTag, firstTag);
			}
			return this;
		}

		public BuilderUpdateWrapper aliasFirstTagEq(String aliasFirstTag) {
			if (StringUtil.isNotBlank(aliasFirstTag)) {
				updateWrapper.eq(RwdDefFuncidWd::getAliasFirstTag, aliasFirstTag);
			}
			return this;
		}

		public BuilderUpdateWrapper secondTagEq(String secondTag) {
			if (StringUtil.isNotBlank(secondTag)) {
				updateWrapper.eq(RwdDefFuncidWd::getSecondTag, secondTag);
			}
			return this;
		}

		public BuilderUpdateWrapper aliasSecondTagEq(String aliasSecondTag) {
			if (StringUtil.isNotBlank(aliasSecondTag)) {
				updateWrapper.eq(RwdDefFuncidWd::getAliasSecondTag, aliasSecondTag);
			}
			return this;
		}

		public BuilderUpdateWrapper priorityEq(String priority) {
			if (StringUtil.isNotBlank(priority)) {
				updateWrapper.eq(RwdDefFuncidWd::getPriority, priority);
			}
			return this;
		}

		public BuilderUpdateWrapper inputModeEq(String inputMode) {
			if (StringUtil.isNotBlank(inputMode)) {
				updateWrapper.eq(RwdDefFuncidWd::getInputMode, inputMode);
			}
			return this;
		}

		public BuilderUpdateWrapper unitEq(String unit) {
			if (StringUtil.isNotBlank(unit)) {
				updateWrapper.eq(RwdDefFuncidWd::getUnit, unit);
			}
			return this;
		}

		public BuilderUpdateWrapper dataTypeEq(String dataType) {
			if (StringUtil.isNotBlank(dataType)) {
				updateWrapper.eq(RwdDefFuncidWd::getDataType, dataType);
			}
			return this;
		}

		public BuilderUpdateWrapper origDataTypeEq(String origDataType) {
			if (StringUtil.isNotBlank(origDataType)) {
				updateWrapper.eq(RwdDefFuncidWd::getOrigDataType, origDataType);
			}
			return this;
		}

		public BuilderUpdateWrapper isMultipleEq(Integer isMultiple) {
			if (null != isMultiple) {
				updateWrapper.eq(RwdDefFuncidWd::getIsMultiple, isMultiple);
			}
			return this;
		}

		public BuilderUpdateWrapper isRegionEq(Integer isRegion) {
			if (null != isRegion) {
				updateWrapper.eq(RwdDefFuncidWd::getIsRegion, isRegion);
			}
			return this;
		}

		public BuilderUpdateWrapper formaterEq(String formater) {
			if (StringUtil.isNotBlank(formater)) {
				updateWrapper.eq(RwdDefFuncidWd::getFormater, formater);
			}
			return this;
		}

		public BuilderUpdateWrapper dataSourceEq(Object dataSource) {
			if (null != dataSource) {
				updateWrapper.eq(RwdDefFuncidWd::getDataSource, dataSource);
			}
			return this;
		}

		public BuilderUpdateWrapper origDataSourceEq(String origDataSource) {
			if (StringUtil.isNotBlank(origDataSource)) {
				updateWrapper.eq(RwdDefFuncidWd::getOrigDataSource, origDataSource);
			}
			return this;
		}

		public BuilderUpdateWrapper noteEq(String note) {
			if (StringUtil.isNotBlank(note)) {
				updateWrapper.eq(RwdDefFuncidWd::getNote, note);
			}
			return this;
		}

		public BuilderUpdateWrapper subFlagEq(Integer subFlag) {
			if (null != subFlag) {
				updateWrapper.eq(RwdDefFuncidWd::getSubFlag, subFlag);
			}
			return this;
		}

		public BuilderUpdateWrapper weakPointEq(Integer weakPoint) {
			if (null != weakPoint) {
				updateWrapper.eq(RwdDefFuncidWd::getWeakPoint, weakPoint);
			}
			return this;
		}

		public LambdaUpdateWrapper<RwdDefFuncidWd> builder() {
			return updateWrapper;
		}

	}

	public static class Builder {

		private RwdDefFuncidWd rwdDefFuncidWd = new RwdDefFuncidWd();

		public Builder id(String id) {
			rwdDefFuncidWd.setId(id);
			return this;
		}

		public Builder code(String code) {
			rwdDefFuncidWd.setCode(code);
			return this;
		}

		public Builder origCode(String origCode) {
			rwdDefFuncidWd.setOrigCode(origCode);
			return this;
		}

		public Builder name(String name) {
			rwdDefFuncidWd.setName(name);
			return this;
		}

		public Builder aliasCode(String aliasCode) {
			rwdDefFuncidWd.setAliasCode(aliasCode);
			return this;
		}

		public Builder aliasName(String aliasName) {
			rwdDefFuncidWd.setAliasName(aliasName);
			return this;
		}

		public Builder classCode(String classCode) {
			rwdDefFuncidWd.setClassCode(classCode);
			return this;
		}

		public Builder type(String type) {
			rwdDefFuncidWd.setType(type);
			return this;
		}

		public Builder groupCode(String groupCode) {
			rwdDefFuncidWd.setGroupCode(groupCode);
			return this;
		}

		public Builder projectId(String projectId) {
			rwdDefFuncidWd.setProjectId(projectId);
			return this;
		}

		public Builder category(String category) {
			rwdDefFuncidWd.setCategory(category);
			return this;
		}

		public Builder firstTag(String firstTag) {
			rwdDefFuncidWd.setFirstTag(firstTag);
			return this;
		}

		public Builder aliasFirstTag(String aliasFirstTag) {
			rwdDefFuncidWd.setAliasFirstTag(aliasFirstTag);
			return this;
		}

		public Builder secondTag(String secondTag) {
			rwdDefFuncidWd.setSecondTag(secondTag);
			return this;
		}

		public Builder aliasSecondTag(String aliasSecondTag) {
			rwdDefFuncidWd.setAliasSecondTag(aliasSecondTag);
			return this;
		}

		public Builder priority(String priority) {
			rwdDefFuncidWd.setPriority(priority);
			return this;
		}

		public Builder inputMode(String inputMode) {
			rwdDefFuncidWd.setInputMode(inputMode);
			return this;
		}

		public Builder unit(String unit) {
			rwdDefFuncidWd.setUnit(unit);
			return this;
		}

		public Builder dataType(String dataType) {
			rwdDefFuncidWd.setDataType(dataType);
			return this;
		}

		public Builder origDataType(String origDataType) {
			rwdDefFuncidWd.setOrigDataType(origDataType);
			return this;
		}

		public Builder isMultiple(Integer isMultiple) {
			rwdDefFuncidWd.setIsMultiple(isMultiple);
			return this;
		}

		public Builder isRegion(Integer isRegion) {
			rwdDefFuncidWd.setIsRegion(isRegion);
			return this;
		}

		public Builder formater(String formater) {
			rwdDefFuncidWd.setFormater(formater);
			return this;
		}

		public Builder dataSource(Object dataSource) {
			rwdDefFuncidWd.setDataSource(dataSource);
			return this;
		}

		public Builder origDataSource(String origDataSource) {
			rwdDefFuncidWd.setOrigDataSource(origDataSource);
			return this;
		}

		public Builder note(String note) {
			rwdDefFuncidWd.setNote(note);
			return this;
		}

		public Builder subFlag(Integer subFlag) {
			rwdDefFuncidWd.setSubFlag(subFlag);
			return this;
		}

		public Builder weakPoint(Integer weakPoint) {
			rwdDefFuncidWd.setWeakPoint(weakPoint);
			return this;
		}

		public RwdDefFuncidWd build() {
			return rwdDefFuncidWd;
		}

	}
}
